@@ -219,7 +219,7 @@ my $total=0;
             pretty_date( $task->start ),
             pretty_date( $task->stop ),
             (   $self->detail
-                ? ( $time, $task->description_short, $file->stringify )
+                ? ( $time, $task->description_short // '', $file->stringify )
                 : ()
             ),
         );
@@ -355,7 +355,7 @@ sub _print_report_tree {
                 say sprintf( $padding. $tagpadding . $format.'   %s',
                     $tag, $self->beautify_seconds($time), $desc );
             }
-            elsif ($detail eq 'tags') {
+            elsif ($detail eq 'tag') {
                 say sprintf( $padding. $tagpadding . $format,
                     $tag, $self->beautify_seconds($time) );
             }
@@ -639,7 +639,7 @@ App::TimeTracker::Command::Core - App::TimeTracker Core commands
 
 =head1 VERSION
 
-version 2.024
+version 2.025
 
 =head1 CORE COMMANDS
 
@@ -704,11 +704,11 @@ Example:
 
     ~$ tracker start --project ExplainContinue --tag testing
     Started working on ExplainContinue (testing) at 12:42
-    
+
     # ... time passes, it's now 13:17
     ~$ tracker stop
     Worked 00:35:00 on ExplainContinue
-    
+
     # back from lunch at 13:58
     ~$ tracker continue
     Started working on ExplainContinue (testing) at 13:58
@@ -717,7 +717,7 @@ Example:
 
 same as L<start|/start>
 
-=head2 append 
+=head2 append
 
     ~/perl/Your-Project$ tracker append
 
@@ -727,11 +727,11 @@ Example:
 
     ~$ tracker start --project ExplainAppend --tag RT1234
     Started working on ExplainAppend (RT1234) at 14:23
-    
+
     # ... time passes (14:46)
     ~$ tracker stop
     Worked 00:23:00 on ExplainAppend (RT1234)
-    
+
     # start working on new ticket
     # ...
     # but forgot to hit start (14:53)
@@ -818,7 +818,7 @@ Lists all found trackfiles and their respective duration before printing out the
 
     ~/perl/Your-Project$ tracker list
 
-Print out a detailed report of what you did in a tabular format including start and stop 
+Print out a detailed report of what you did in a tabular format including start and stop
 times.
 
 =head3 Options:
@@ -879,7 +879,7 @@ Thomas Klausner <domm@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Thomas Klausner.
+This software is copyright (c) 2011 - 2018 by Thomas Klausner.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
